@@ -40,9 +40,15 @@ class MouseCursor {
     float idle;
     float timeout;
     
+    int scrollwheel;
+    
     SDL_Cursor* sdl_default_cursor;
     SDL_Cursor* sdl_hidden_cursor;
 
+    bool left_click;
+    bool right_click;
+    bool middle_click;
+
     TextureResource* cursortex;
 public:
     MouseCursor();
@@ -50,16 +56,30 @@ public:
     
     vec2 getPos() const { return mousepos; }
 
+    void leftClick(bool click);
+    void rightClick(bool click);
+    void middleClick(bool click);
+
+    bool leftClick() const;
+    bool rightClick() const;
+    bool middleClick() const;
+    
     bool leftButtonPressed() const;
     bool rightButtonPressed() const;
     bool bothPressed() const;
     bool buttonPressed() const;
 
+    int scrollWheel() const;
+    
     bool isHidden() const;
     bool isSystemCursor()const;
     bool isVisible() const;
     bool hasFocus() const;
 
+    void scroll(bool dir);
+
+    void resetButtonState();
+
     void updatePos(const vec2& pos);
 
     void showCursor(bool show);
