@@ -122,7 +122,6 @@ bool RCommitLog::checkFirstChar(int firstChar, std::istream& stream) {
 }
 
 bool RCommitLog::checkFormat() {
-
     if(!success) return false;
 
     //read a commit to see if the log is in the correct format
@@ -208,6 +207,11 @@ bool RCommitLog::findNextCommit(RCommit& commit, int attempts) {
     return false;
 }
 
+void RCommitLog::bufferCommit(RCommit& commit) {
+    lastCommit = commit;
+    buffered = true;
+}
+
 bool RCommitLog::nextCommit(RCommit& commit, bool validate) {
 
     if(buffered) {
@@ -233,13 +237,17 @@ bool RCommitLog::isFinished() {
     return false;
 }
 
+bool RCommitLog::hasBufferedCommit() {
+    return buffered;
+}
+
 //create temp file
 void RCommitLog::createTempLog() {
 
     std::string tempdir;
 
 #ifdef _WIN32
-    DWORD tmplen = GetTempPath(0, "");
+    DWORD tmplen = GetTempPath(0, 0);
 
     if(tmplen == 0) return;
 
